import{g as c}from"./api.387ddd94.js";import{P as m}from"./Passwordless.1616ae72.js";import{a as p}from"./asyncComputed.eebec89e.js";import{W as u}from"./WidgetsFrame.8301aa17.js";import{d as f,eA as l,eB as _,b as d,ev as y,e as g,u as a,c as b,w as h,ex as w,f as v,v as k}from"./outputWidgets.83ad65aa.js";import"./runnerData.83b2a9f7.js";import"./url.27ce9387.js";import"./index.294557b8.js";import"./pubsub.6c6cbc8d.js";import"./icons.ec92f7f9.js";import"./CircularLoading.05e42a56.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="2bfd1d69-41a5-4de9-aa1c-da2b0ed86a3e",e._sentryDebugIdIdentifier="sentry-dbid-2bfd1d69-41a5-4de9-aa1c-da2b0ed86a3e")}catch{}})();const x={class:"login"},I=f({__name:"Login",setup(e){const t=l(),s=_(),{result:o}=p(c),i=()=>{const{redirect:r,...n}=s.query;if(r){t.push({path:r,query:n,params:s.params});return}t.push({name:"playerKanban",query:n})};return(r,n)=>(d(),y("div",null,[g("div",x,[a(o)?(d(),b(u,{key:0,"main-color":a(o).mainColor,theme:a(o).theme,"font-family":a(o).fontFamily,style:{width:"100vw"}},{default:h(()=>[v(m,{onDone:i})]),_:1},8,["main-color","theme","font-family"])):w("",!0)])]))}});const R=k(I,[["__scopeId","data-v-33714d9d"]]);export{R as default};
//# sourceMappingURL=Login.961969de.js.map
