import{V as s,f as p,Q as d}from"./outputWidgets.83ad65aa.js";import{B as f,b as i}from"./Base.5de97c83.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[a]="88c7a623-0167-4b34-8bc3-2b6f124167f7",r._sentryDebugIdIdentifier="sentry-dbid-88c7a623-0167-4b34-8bc3-2b6f124167f7")}catch{}})();const b=()=>d(i(),["component"]),e=(r,a)=>{let{slots:t,attrs:o}=a;const n=s(s(s({},r),{component:"div"}),o);return p(f,n,t)};e.displayName="ATypographyParagraph";e.inheritAttrs=!1;e.props=b();const g=e;export{g as A};
//# sourceMappingURL=Paragraph.eee68d2f.js.map
