import{d as b,eB as y,H as g,b as _,c as w,u as h}from"./outputWidgets.83ad65aa.js";import{a as I}from"./asyncComputed.eebec89e.js";import{b as k}from"./router.1b8539af.js";import"./index.9f577453.js";import{M as n}from"./member.c760a247.js";import{C as x}from"./CrudView.fb55c5f4.js";import{K as C}from"./icons.ec92f7f9.js";import{a as M}from"./ant-design.a75cbb2f.js";import"./Form.5deb3adb.js";import"./hasIn.597d0078.js";import"./index.cf4c23b9.js";import"./record.df4e3ae7.js";import"./pubsub.6c6cbc8d.js";import"./Paragraph.eee68d2f.js";import"./Base.5de97c83.js";import"./Typography.fea800b8.js";import"./Modal.00c72438.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.d125b27a.js";import"./url.27ce9387.js";import"./index.677f843d.js";import"./Title.50be6d8b.js";import"./Text.72dc1978.js";import"./index.06a93781.js";import"./index.dbec653f.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[i]="d6115093-412c-466f-a5b0-4c76e44c8ad3",t._sentryDebugIdIdentifier="sentry-dbid-d6115093-412c-466f-a5b0-4c76e44c8ad3")}catch{}})();const X=b({__name:"Members",setup(t){const a=y().params.organizationId,l=[{key:"email",label:"Email"}],c=async e=>{await n.create(a,e.email),m()};async function d(e){await M("Are you sure you want to remove this member's access?")&&(await n.delete(a,e.authorId),m())}const{loading:p,result:u,refetch:m}=I(()=>n.list(a)),f=g(()=>{var e,r;return{columns:[{name:"Email",align:"left"},{name:"Role"},{name:"",align:"right"}],rows:(r=(e=u.value)==null?void 0:e.map(o=>{var s;return{key:o.email,cells:[{type:"text",text:o.email},{type:"text",text:o.role},{type:"actions",actions:((s=k.getAuthor())==null?void 0:s.claims.email)===o.email?[]:[{icon:C,label:"Remove access",onClick:()=>d(o),dangerous:!0}]}]}}))!=null?r:[]}});return(e,r)=>(_(),w(x,{"entity-name":"members",loading:h(p),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:f.value,"create-button-text":"Add members",fields:l,onCreate:c},null,8,["loading","table"]))}});export{X as default};
//# sourceMappingURL=Members.21c5ee81.js.map
