import"./outputWidgets.83ad65aa.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="2d8a8dfa-dcf0-4df2-b283-e1eeecf4592c",e._sentryDebugIdIdentifier="sentry-dbid-2d8a8dfa-dcf0-4df2-b283-e1eeecf4592c")}catch{}})();function d(e){return e.charAt(0).toUpperCase()+e.slice(1)}function i(e,a,n=!1,o=!0){const r=(o?e.toLocaleLowerCase():e).replace(/[^a-zA-Z0-9]/g,"_"),s=n?r:r.replace(/_+/g,"_");return a?s:s.replace(/_$/,"")}function l(e){var r;const n=e.toLocaleLowerCase().trim().normalize("NFD").replace(/[\u0300-\u036f]/g,""),o=/[a-z0-9]+/g,t=n.match(o);return(r=t==null?void 0:t.join("-"))!=null?r:""}function f(e){try{return{valid:!0,parsed:JSON.parse(e)}}catch(a){return{valid:!1,message:a.message}}}export{l as a,d as c,i as n,f as v};
//# sourceMappingURL=string.ce2eea25.js.map
