.flex-row[data-v-dc7e11a2]{display:flex;flex-direction:row;align-items:center;justify-content:right;gap:5px;height:100%;width:100%}.trigger-buttons[data-v-5bc0258e]{display:flex;gap:8px;font-size:14px;color:gray}.trigger-buttons>*[data-v-5bc0258e]{cursor:pointer}.trigger-buttons>*[data-v-5bc0258e] :hover{color:#f28392}.trigger-buttons>*[data-v-5bc0258e] :active{color:#f28392}
