import{z as e}from"./index.cf4c23b9.js";import"./outputWidgets.83ad65aa.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="286e1653-210b-4126-8210-566631465e26",t._sentryDebugIdIdentifier="sentry-dbid-286e1653-210b-4126-8210-566631465e26")}catch{}})();const p=e.boolean(),g=e.boolean(),S=e.boolean(),u=e.boolean();e.object({PROJECT_LIVE:p.optional(),ALLOW_RELEASE:g.optional(),CONNECTORS_CONSOLE:S.optional(),DUPLICATE_PROJECTS:u.optional()});const C=e.string();e.object({plan:C.optional()});const A=e.string(),h=e.string(),d=e.string(),R=e.string(),L=e.string().regex(new RegExp("^[0-9]+m$")),y=e.string().regex(new RegExp("^[0-9]+m$")),E=e.string().regex(new RegExp("^[0-9]+Mi$")),O=e.string().regex(new RegExp("^[0-9]+Mi$")),P=e.string().regex(new RegExp("^[0-9]+$")),x=e.string().regex(new RegExp("^[0-9]+$")),I=e.enum(["shared","clickbus","test"]),j=e.object({requestsCPU:L.optional(),limitsCPU:y.optional(),requestsMemory:E.optional(),limitsMemory:O.optional(),minReplicas:P.optional(),timeoutSeconds:x.optional(),workerType:I.optional()});e.object({id:A,name:h,subdomain:d,organizationId:R,deploymentResources:j.optional()});const M=e.string().regex(new RegExp("^[0-9]+m$")),w=e.string().regex(new RegExp("^[0-9]+m$")),D=e.string().regex(new RegExp("^[0-9]+Mi$")),z=e.string().regex(new RegExp("^[0-9]+Mi$")),T=e.string().regex(new RegExp("^[0-9]+$")),U=e.string().regex(new RegExp("^[0-9]+$")),F=e.enum(["shared","clickbus","test"]);e.object({requestsCPU:M.optional(),limitsCPU:w.optional(),requestsMemory:D.optional(),limitsMemory:z.optional(),minReplicas:T.optional(),timeoutSeconds:U.optional(),workerType:F.optional()});const _=e.string(),n=e.string(),f=e.literal("workflow_viewer"),It=["workflow_viewer"],o=e.array(f),N=e.string(),q=e.string(),$=e.object({id:_,email:n,roles:o,projectId:N,createdAt:q}),s=e.string(),i=e.string(),k=e.boolean(),V=e.boolean(),K=e.boolean(),W=e.boolean(),r=e.object({PROJECT_LIVE:k,ALLOW_RELEASE:V,CONNECTORS_CONSOLE:K,DUPLICATE_PROJECTS:W}),v=e.string(),c=e.object({plan:v.optional()}),J=e.string().regex(new RegExp("^[0-9]+m$")),B=e.string().regex(new RegExp("^[0-9]+m$")),G=e.string().regex(new RegExp("^[0-9]+Mi$")),Q=e.string().regex(new RegExp("^[0-9]+Mi$")),H=e.string().regex(new RegExp("^[0-9]+$")),X=e.string().regex(new RegExp("^[0-9]+$")),Y=e.enum(["shared","clickbus","test"]),Z=e.object({requestsCPU:J.optional(),limitsCPU:B.optional(),requestsMemory:G.optional(),limitsMemory:Q.optional(),minReplicas:H.optional(),timeoutSeconds:X.optional(),workerType:Y.optional()}),ee=e.string(),te=e.array(ee),oe=e.object({whitelistPatterns:te.optional()});e.object({id:s,name:i,featureFlags:r,billingMetadata:c,deploymentResources:Z.optional(),membershipsMetadata:oe.optional()});const ae=e.string(),ne=e.array(ae);e.object({whitelistPatterns:ne.optional()});const se=s,ie=i,re=r,ce=c;e.object({id:se,name:ie,featureFlags:re,billingMetadata:ce});const me=o;e.object({roles:me});const le=e.number(),be=e.number();e.object({offset:le.optional(),limit:be.optional()});const pe=$;e.array(pe);const ge=n,Se=o;e.object({email:ge,roles:Se});const ue=e.boolean();e.object({shouldBeOnboarded:ue.optional()});const Ce=e.string(),Ae=e.string(),he=e.string(),de=e.string();e.object({name:Ce.optional(),companyName:Ae.optional(),source:he.optional(),authorEmail:de.optional()});const Re=e.string(),Le=e.record(e.any()),ye=e.string(),Ee=e.object({key:Re,value:Le,type:ye}),Oe=Ee,Pe=e.array(Oe),xe=e.string(),Ie=e.enum(["text","image","table","progress-bar"]),je=e.object({name:xe,type:Ie}),Me=e.string(),we=e.string(),De=e.record(e.any()),m=e.enum(["waiting","running","finished","failed","abandoned"]),jt=["waiting","running","finished","failed","abandoned"],ze=e.string(),Te=e.string(),Ue=e.string();e.object({id:Me,stage:we,data:De,status:m,created_at:ze,parent_id:Te.optional(),execution_id:Ue.optional()});const Fe=e.string(),_e=e.string(),fe=e.string(),Ne=m,qe=Pe,$e=e.object({id:Fe,created_at:_e,assignee:fe.optional(),status:Ne,content:qe}),ke=$e,Ve=e.array(ke),Ke=e.string(),We=e.enum(["form","hook","job","script","iterator","condition"]),ve=e.string(),Je=e.string(),Be=e.boolean(),l=e.object({id:Ke,type:We,title:ve,path:Je.optional(),can_be_started:Be}),Ge=l,Qe=Ve,He=l,b=e.array(He),Xe=b,Ye=e.number(),Ze=e.object({selected_stage:Ge,stage_run_cards:Qe,stages:Xe,total_count:Ye}),et=Ze,tt=e.array(et),ot=tt,at=b;e.object({columns:ot,next_stage_options:at});const nt=je;e.array(nt);const st=e.string(),it=e.string(),rt=e.literal("bug"),ct=e.string(),mt=e.string(),lt=e.string(),bt=e.object({name:mt,label:lt}),pt=bt,gt=e.array(pt),St=e.object({label:ct,fixes:gt}),ut=St,Ct=e.array(ut),At=e.object({name:st,label:it,type:rt,issues:Ct}),ht=e.boolean();e.object({success:ht});const dt=At;e.array(dt);const Rt=e.string(),Lt=e.string(),yt=e.object({key:Rt,value:Lt}),Et=yt;e.array(Et);export{jt as A,It as C};
//# sourceMappingURL=contracts.generated.2d369aba.js.map
