import{K as n,E as a,L as p}from"./repository.75aa997f.js";import{d as s,b as m,c as d,u as e}from"./outputWidgets.83ad65aa.js";import{l as c}from"./index.294557b8.js";import"./asyncComputed.eebec89e.js";import"./api.62145a2a.js";import"./index.cf4c23b9.js";import"./icons.ec92f7f9.js";import"./index.677f843d.js";import"./ant-design.a75cbb2f.js";import"./index.dbec653f.js";import"./Modal.00c72438.js";import"./Text.72dc1978.js";import"./Base.5de97c83.js";import"./Typography.fea800b8.js";import"./index.06a93781.js";import"./index.df49dc57.js";import"./Paragraph.eee68d2f.js";import"./index.ba9c8b50.js";import"./Link.4990aa3d.js";import"./Title.50be6d8b.js";import"./index.8fc96f75.js";import"./CollapsePanel.a1c19e5e.js";import"./Form.5deb3adb.js";import"./hasIn.597d0078.js";import"./Timeline.5fe53314.js";import"./index.1855b9aa.js";import"./index.7c735672.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.2d369aba.js";import"./workspaces.a03a836c.js";import"./runnerData.83b2a9f7.js";import"./url.27ce9387.js";import"./record.df4e3ae7.js";import"./pubsub.6c6cbc8d.js";import"./scripts.6970ec03.js";import"./envVars.f18fb294.js";import"./ExpandOutlined.c6062942.js";import"./Card.e59afab4.js";import"./TabPane.b3ba7cb7.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="71ddd73b-84b3-4fea-a3ae-7a468d861787",t._sentryDebugIdIdentifier="sentry-dbid-71ddd73b-84b3-4fea-a3ae-7a468d861787")}catch{}})();class f{constructor(o=c){this.fetch=o}async fork(o){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:o}),headers:{"Content-Type":"application/json"}})).json()}}const oo=s({__name:"WorkflowKanban",setup(t){const o=new a,r=new f,i=new p("kanban");return(u,b)=>(m(),d(n,{"kanban-repository":e(o),storage:e(i),"stage-run-repository":e(r)},null,8,["kanban-repository","storage","stage-run-repository"]))}});export{oo as default};
//# sourceMappingURL=WorkflowKanban.06c1c1ed.js.map
