import{v as t,b as a,ev as s}from"./outputWidgets.83ad65aa.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="a8f6b5aa-20cc-4c0d-86a9-12a2d8e5d2c6",e._sentryDebugIdIdentifier="sentry-dbid-a8f6b5aa-20cc-4c0d-86a9-12a2d8e5d2c6")}catch{}})();const c={},d={class:"organization-settings"};function o(e,n){return a(),s("div",d,"Organization settings")}const f=t(c,[["render",o]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.ddfc9469.js.map
