import{r as a,w as r}from"./runnerData.83b2a9f7.js";import"./outputWidgets.83ad65aa.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="3d98c0e6-5019-47a5-84b4-eefd9eae16d2",e._sentryDebugIdIdentifier="sentry-dbid-3d98c0e6-5019-47a5-84b4-eefd9eae16d2")}catch{}})();async function f(e){const t=await fetch(`/_pages/${e}`);if(t.status==404)return null;if(!t.ok)throw new Error(await t.text());const{form:n}=await t.json();return n?a(n):null}async function u(){const e=await fetch("/_workspace");if(e.status!=200)return r({});const t=await e.json();return r(t)}export{f,u as g};
//# sourceMappingURL=api.387ddd94.js.map
