import{C as t,A as m}from"./CollapsePanel.a1c19e5e.js";import{F as n}from"./Form.5deb3adb.js";import{aM as c,co as r}from"./outputWidgets.83ad65aa.js";import{T as o,A as s}from"./Timeline.5fe53314.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[i]="b8981902-9874-4c55-b697-f505b2e429cd",e._sentryDebugIdIdentifier="sentry-dbid-b8981902-9874-4c55-b697-f505b2e429cd")}catch{}})();t.Panel=m;t.install=function(e){return e.component(t.name,t),e.component(m.name,m),e};n.useInjectFormItemContext=c;n.ItemRest=r;n.install=function(e){return e.component(n.name,n),e.component(n.Item.name,n.Item),e.component(r.name,r),e};o.Item=s;o.install=function(e){return e.component(o.name,o),e.component(s.name,s),e};
//# sourceMappingURL=index.8fc96f75.js.map
