import{eN as t,eO as a}from"./outputWidgets.83ad65aa.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="a8786aee-fedd-453b-a18e-5cd71590a696",e._sentryDebugIdIdentifier="sentry-dbid-a8786aee-fedd-453b-a18e-5cd71590a696")}catch{}})();function o(e,n){return t(1,arguments),a(e,Date.now(),n)}export{o as f};
//# sourceMappingURL=index.df49dc57.js.map
