import{ac as d,V as t,Q as r,f as p}from"./outputWidgets.83ad65aa.js";import{B as f,b as l}from"./Base.5de97c83.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="769544ca-1618-4188-a1c1-05c4aa8fc468",e._sentryDebugIdIdentifier="sentry-dbid-769544ca-1618-4188-a1c1-05c4aa8fc468")}catch{}})();const y=()=>t(t({},r(l(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),a=(e,s)=>{let{slots:o,attrs:c}=s;const{ellipsis:n}=e;d();const i=t(t(t({},e),{ellipsis:n&&typeof n=="object"?r(n,["expandable","rows"]):n,component:"span"}),c);return p(f,i,o)};a.displayName="ATypographyText";a.inheritAttrs=!1;a.props=y();const g=a;export{g as A};
//# sourceMappingURL=Text.72dc1978.js.map
