import{B as i}from"./Base.5de97c83.js";import{A as a}from"./Link.4990aa3d.js";import{A as o}from"./Paragraph.eee68d2f.js";import{A as r}from"./Text.72dc1978.js";import{A as f}from"./Title.50be6d8b.js";import{T as e}from"./Typography.fea800b8.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="35780a79-f31d-40f6-9ef6-b458fa76af0e",n._sentryDebugIdIdentifier="sentry-dbid-35780a79-f31d-40f6-9ef6-b458fa76af0e")}catch{}})();e.Text=r;e.Title=f;e.Paragraph=o;e.Link=a;e.Base=i;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,r),n.component(e.Title.displayName,f),n.component(e.Paragraph.displayName,o),n.component(e.Link.displayName,a),n};
//# sourceMappingURL=index.ba9c8b50.js.map
