import{S as p}from"./Sidebar.37204cbd.js";import{_ as d}from"./Navbar.vue_vue_type_script_setup_true_lang.613af5f6.js";import{L as c,M as b,N as l}from"./icons.ec92f7f9.js";import{d as u,eB as f,H as g,a as _,b as y,c as v,w as a,f as r}from"./outputWidgets.83ad65aa.js";import{a as w}from"./asyncComputed.eebec89e.js";import"./router.1b8539af.js";import"./index.9f577453.js";import{O as z}from"./organization.84b53f22.js";import{B as h}from"./BaseLayout.5a1484a1.js";import"./index.06a93781.js";import"./logo.084e5d7c.js";import"./Text.72dc1978.js";import"./Base.5de97c83.js";import"./Typography.fea800b8.js";import"./index.b1fc61d4.js";import"./ArrowRightOutlined.08fa31dd.js";import"./Form.5deb3adb.js";import"./hasIn.597d0078.js";import"./index.cf4c23b9.js";import"./record.df4e3ae7.js";import"./pubsub.6c6cbc8d.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="d92b7640-fad0-4fbd-b656-de648b2e10eb",o._sentryDebugIdIdentifier="sentry-dbid-d92b7640-fad0-4fbd-b656-de648b2e10eb")}catch{}})();const K=u({__name:"Organization",setup(o){const n=f().params.organizationId,{result:t}=w(()=>z.get(n)),i=g(()=>t.value?[{label:"My organizations",path:"/organizations"},{label:t.value.name,path:`/organizations/${t.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:c,path:"projects"},{name:"Members",icon:b,path:"members"},{name:"Billing",icon:l,path:"billing"}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:a(()=>[r(d,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:a(()=>[r(p,{class:"sidebar",sections:s})]),content:a(()=>[r(m)]),_:1})}}});export{K as default};
//# sourceMappingURL=Organization.03a9efe4.js.map
