import{cz as d}from"./outputWidgets.83ad65aa.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="d980b0ea-0cd9-44c7-ac9a-747447340459",e._sentryDebugIdIdentifier="sentry-dbid-d980b0ea-0cd9-44c7-ac9a-747447340459")}catch{}})();const t=(e,r)=>{d.error({message:e,description:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.420f66fa.js.map
