import{v as a,a as r,b as i,c,j as d,T as p,k as f,P as _,C as u,M as l,s as g,l as s,m,n as y,p as v,q as b}from"./outputWidgets.83ad65aa.js";import{s as w,a as o}from"./index.294557b8.js";import"./pubsub.6c6cbc8d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="a5fc76a3-c00a-48fd-93f5-61760d748c30",e._sentryDebugIdIdentifier="sentry-dbid-a5fc76a3-c00a-48fd-93f5-61760d748c30")}catch{}})();const h={};function I(e,t){const n=r("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const k=a(h,[["render",I]]);class x{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await w();const e=d({render:()=>m(k)});p.init(),f(e,o),x.init(),e.use(o),e.use(_),e.mount("#app"),e.component("VSelect",u),e.component("Markdown",l),e.component("Message",g),s(e,y),s(e,v),s(e,b)})();
//# sourceMappingURL=player.46f783bd.js.map
