import{_ as s}from"./Navbar.vue_vue_type_script_setup_true_lang.b8bb3e5c.js";import{K as d,P as f,L as b}from"./repository.75aa997f.js";import{d as l,b as u,ev as c,f as p,u as r}from"./outputWidgets.83ad65aa.js";import{u as g}from"./index.294557b8.js";import{a as y}from"./asyncComputed.eebec89e.js";import{g as _}from"./api.387ddd94.js";import"./Text.72dc1978.js";import"./Base.5de97c83.js";import"./Typography.fea800b8.js";import"./index.ba9c8b50.js";import"./Link.4990aa3d.js";import"./Paragraph.eee68d2f.js";import"./Title.50be6d8b.js";import"./index.b1fc61d4.js";import"./ArrowRightOutlined.08fa31dd.js";import"./api.62145a2a.js";import"./index.cf4c23b9.js";import"./icons.ec92f7f9.js";import"./index.677f843d.js";import"./ant-design.a75cbb2f.js";import"./index.dbec653f.js";import"./Modal.00c72438.js";import"./index.06a93781.js";import"./index.df49dc57.js";import"./index.8fc96f75.js";import"./CollapsePanel.a1c19e5e.js";import"./Form.5deb3adb.js";import"./hasIn.597d0078.js";import"./Timeline.5fe53314.js";import"./index.1855b9aa.js";import"./index.7c735672.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.2d369aba.js";import"./workspaces.a03a836c.js";import"./runnerData.83b2a9f7.js";import"./url.27ce9387.js";import"./record.df4e3ae7.js";import"./pubsub.6c6cbc8d.js";import"./scripts.6970ec03.js";import"./envVars.f18fb294.js";import"./ExpandOutlined.c6062942.js";import"./Card.e59afab4.js";import"./TabPane.b3ba7cb7.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="5e028fc9-d688-44bb-8e95-0749ff323d6b",o._sentryDebugIdIdentifier="sentry-dbid-5e028fc9-d688-44bb-8e95-0749ff323d6b")}catch{}})();const fo=l({__name:"Kanban",setup(o){const t=new f(g),i=new b("kanban"),{result:e}=y(_);return(k,w)=>{var n,a,m;return u(),c("div",null,[p(s,{"brand-name":((n=r(e))==null?void 0:n.brandName)||((a=r(e))==null?void 0:a.name),"logo-url":(m=r(e))==null?void 0:m.logoUrl},null,8,["brand-name","logo-url"]),p(d,{"kanban-repository":r(t),storage:r(i)},null,8,["kanban-repository","storage"])])}}});export{fo as default};
//# sourceMappingURL=Kanban.defa5c94.js.map
