import"./outputWidgets.83ad65aa.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ac9cc7a6-df1c-4c13-8438-18eb2b65d8c5",e._sentryDebugIdIdentifier="sentry-dbid-ac9cc7a6-df1c-4c13-8438-18eb2b65d8c5")}catch{}})();const c=e=>{try{return new URL(e),!0}catch{return!1}};export{c as i};
//# sourceMappingURL=url.27ce9387.js.map
